@@ -2,7 +2,7 @@
 
 from django.conf.urls.defaults import *
 from rblog.feeds import AllFeed, TagFeed
-from rblog.views import BlogIndexView, PostDetailView, PostsWithTag, PostsByDate, AJAXArchive, cronAddDisqusComments
+from rblog.views import BlogIndexView, PostDetailView, PostsWithTag, PostsByDate, AJAXArchive
 from django.views.decorators.cache import cache_page
 
 
@@ -19,8 +19,6 @@ urlpatterns = patterns('',
     url(r'^feed.rss$',                             AllFeed(), {}, 'app_blog-feed2'),
     # 1 day cache
     url(r'^ajax/testing/$',                        cache_page(60 * 24)(AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
-    # cron Disqus comments sync
-    url(r'^cron/disqus/$',                        cronAddDisqusComments),
 )
 
 
